@@ -25,10 +25,11 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
 #include "Interpret.h"
-#include "smt2tokens.h"
-#include "ArithLogic.h"
-#include "LogicFactory.h"
-#include "Substitutor.h"
+
+#include <api/smt2tokens.h>
+#include <logics/ArithLogic.h>
+#include <logics/LogicFactory.h>
+#include <rewriters/Substitutor.h>
 
 #include <string>
 #include <sstream>
@@ -39,11 +40,9 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  * Class defining interpreter
  ***********************************************************/
 
-Interpret::~Interpret() {
-    for (int i = 0; i < term_names.size(); ++i) {
-        free(term_names[i]);
-    }
-}
+namespace opensmt {
+
+Interpret::~Interpret() = default;
 
 PTRef
 Interpret::getParsedFormula()
@@ -133,13 +132,12 @@ void Interpret::exit() {
     f_exit = true;
 }
 
-using opensmt::Logic_t;
-using namespace osmttokens;
+using namespace tokens;
 
 namespace {
-    Logic_t getLogicFromString(std::string_view string_name) {
-        if (string_name == "ALL") { return opensmt::getLogicFromString("QF_AUFLIRA"); }
-        return opensmt::getLogicFromString(string_name);
+    Logic_t getLogicFromStringAux(std::string_view string_name) {
+        if (string_name == "ALL") { return getLogicFromString("QF_AUFLIRA"); }
+        return getLogicFromString(string_name);
     }
 }
 
@@ -154,7 +152,7 @@ void Interpret::interp(ASTNode& n) {
                 if (isInitialized()) {
                     notify_formatted(true, "logic has already been set to %s", main_solver->getLogic().getName().data());
                 } else {
-                    auto logic_type = getLogicFromString(logic_name);
+                    auto logic_type = getLogicFromStringAux(logic_name);
                     if (logic_type == Logic_t::UNDEF) {
                         notify_formatted(true, "unknown logic %s", logic_name);
                         break;
@@ -232,7 +230,7 @@ void Interpret::interp(ASTNode& n) {
                         try {
                             main_solver->insertFormula(tr);
                             notify_success();
-                        } catch (OsmtApiException const & e) {
+                        } catch (ApiException const & e) {
                             notify_formatted(true, e.what());
                         }
                     }
@@ -376,13 +374,13 @@ void Interpret::interp(ASTNode& n) {
                 notify_formatted(true, "Unknown command encountered: %s", tokenToName.at(cmd.x).c_str());
             }
         }
-    } catch (OsmtApiException const &e) {
+    } catch (ApiException const &e) {
         notify_formatted(true, e.what());
     }
 }
 
 bool Interpret::addLetFrame(ASTNode const & bindingsNode, LetRecords & letRecords) {
-    std::vector<opensmt::pair<PTRef, std::string>> bindings;
+    std::vector<pair<PTRef, std::string>> bindings;
 
     // First read the term declarations in the let statement
     for (ASTNode const* vb : *bindingsNode.children) {
@@ -413,7 +411,7 @@ PTRef Interpret::resolveQualifiedIdentifier(const char * name, ASTNode const & s
     PTRef tr = PTRef_Undef;
     try {
         tr = resolveTerm(name, {}, sr, isQuoted ? SymbolMatcher::Uninterpreted : SymbolMatcher::Any);
-    } catch (OsmtApiException & e) {
+    } catch (ApiException & e) {
         reportError(e.what());
     }
     return tr;
@@ -435,7 +433,7 @@ PTRef Interpret::parseTerm(const ASTNode& term, LetRecords& letRecords) {
         PTRef tr = PTRef_Undef;
         try {
             tr = logic->mkConst(name);
-        } catch (OsmtApiException const & e) {
+        } catch (ApiException const & e) {
             comment_formatted("While processing %s: %s", name, e.what());
         }
         return tr;
@@ -462,7 +460,7 @@ PTRef Interpret::parseTerm(const ASTNode& term, LetRecords& letRecords) {
             }
             try {
                 tr = resolveTerm(name, {}, SRef_Undef, isQuoted ? SymbolMatcher::Uninterpreted : SymbolMatcher::Any);
-            } catch (OsmtApiException & e) {
+            } catch (ApiException & e) {
                 reportError(e.what());
             }
             return tr;
@@ -489,7 +487,7 @@ PTRef Interpret::parseTerm(const ASTNode& term, LetRecords& letRecords) {
             tr = resolveTerm(name, std::move(args));
         } catch (ArithDivisionByZeroException &ex) {
             reportError(ex.what());
-        } catch (OsmtApiException &e) {
+        } catch (ApiException &e) {
             reportError(e.what());
         }
         return tr;
@@ -535,19 +533,12 @@ PTRef Interpret::parseTerm(const ASTNode& term, LetRecords& letRecords) {
         if (strcmp(name_attr.getValue(), ":named") == 0) {
             ASTNode& sym = **(name_attr.children->begin());
             assert(sym.getType() == SYM_T or sym.getType() == QSYM_T);
-            if (nameToTerm.has(sym.getValue())) {
-                notify_formatted(true, "name %s already exists", sym.getValue());
+            char const * str = sym.getValue();
+            bool const success = main_solver->tryAddTermNameFor(tr, str);
+            if (not success) {
+                notify_formatted(true, "name %s already exists", str);
                 return PTRef_Undef;
             }
-            char* name = strdup(sym.getValue());
-            // MB: term_names becomes the owner of the string and is responsible for deleting
-            term_names.push(name);
-            nameToTerm.insert(name, tr);
-            if (!termToNames.has(tr)) {
-                vec<const char*> v;
-                termToNames.insert(tr, v);
-            }
-            termToNames[tr].push(name);
         }
         return tr;
     }
@@ -607,7 +598,9 @@ void Interpret::pop(int n) {
             bool success = true;
             while (n-- and success) {
                 success = main_solver->pop();
-                if (success) { defined_functions.popScope(); }
+                if (success) {
+                    defined_functions.popScope();
+                }
             }
             if (success) {
                 notify_success();
@@ -620,27 +613,26 @@ void Interpret::pop(int n) {
     }
 }
 
-bool Interpret::getAssignment() {
+bool Interpret::getAssignment() const {
     if (not isInitialized()) {
        notify_formatted(true, "Illegal command before set-logic");
        return false;
     }
-    if (main_solver->getStatus() != s_True) {
+    auto const & solver = getMainSolver();
+    if (solver.getStatus() != s_True) {
        notify_formatted(true, "Last solver call not satisfiable");
        return false;
     }
-    std::stringstream ss;
+    std::ostringstream ss;
+    auto const & termNames = solver.getTermNames();
     ss << '(';
-    for (int i = 0; i < term_names.size(); i++) {
-        const char* name = term_names[i];
-        PTRef tr = nameToTerm[name];
-        lbool val = main_solver->getTermValue(tr);
-        ss << '(' << name << ' ' << (val == l_True ? "true" : (val == l_False ? "false" : "unknown"))
-            << ')' << (i < term_names.size() - 1 ? " " : "");
+    for (auto const & [name, term] : termNames) {
+        lbool val = solver.getTermValue(term);
+        ss << '(' << name << ' ' << (val == l_True ? "true" : (val == l_False ? "false" : "unknown")) << ')' << " ";
     }
+    ss.seekp(-1, std::ios::cur);
     ss << ')';
-    const std::string& out = ss.str();
-    notify_formatted(false, out.c_str());
+    notify_formatted(false, ss.str().c_str());
     return true;
 }
 
@@ -714,7 +706,7 @@ void Interpret::getValue(std::vector<ASTNode*> const & terms)
 {
     auto model = main_solver->getModel();
     Logic & logic = main_solver->getLogic();
-    using ValPair = opensmt::pair<ASTNode const * const,PTRef>;
+    using ValPair = pair<ASTNode const * const,PTRef>;
     std::vector<ValPair> values;
     for (auto termNode : terms) {
         ASTNode const & term = *termNode;
@@ -1051,7 +1043,7 @@ void Interpret::comment_formatted(const char* fmt_str, ...) const {
 }
 
 
-void Interpret::notify_formatted(bool error, const char* fmt_str, ...) {
+void Interpret::notify_formatted(bool error, const char* fmt_str, ...) const {
     va_list ap;
     int d;
     char c1, *t;
@@ -1086,7 +1078,7 @@ void Interpret::notify_formatted(bool error, const char* fmt_str, ...) {
     std::cout << std::endl;
 }
 
-void Interpret::notify_success() {
+void Interpret::notify_success() const {
     if (config.printSuccess()) {
         std::cout << "success" << std::endl;
     }
@@ -1103,7 +1095,7 @@ void Interpret::execute(const ASTNode* r) {
 
 int Interpret::interpFile(FILE* in) {
     Smt2newContext context(in);
-    int rval = smt2newparse(&context);
+    int rval = osmt_yyparse(&context);
 
     if (rval != 0) return rval;
 
@@ -1114,7 +1106,7 @@ int Interpret::interpFile(FILE* in) {
 
 int Interpret::interpFile(char *content){
     Smt2newContext context(content);
-    int rval = smt2newparse(&context);
+    int rval = osmt_yyparse(&context);
 
     if (rval != 0) return rval;
     const ASTNode* r = context.getRoot();
@@ -1216,7 +1208,7 @@ int Interpret::interpPipe() {
 
                     i = -1; // will be incremented to 0 by the loop condition.
                     Smt2newContext context(buf_out);
-                    int rval = smt2newparse(&context);
+                    int rval = osmt_yyparse(&context);
                     if (rval != 0)
                         notify_formatted(true, "scanner");
                     else {
@@ -1292,16 +1284,8 @@ void Interpret::getProof()
 }
 
 void Interpret::getUnsatCore() {
-    auto unsatCore = main_solver->getUnsatCore();
-    std::cout << "( ";
-    for (PTRef fla : unsatCore) {
-        vec<const char*> names;
-        bool present = termToNames.peek(fla, names);
-        if (not present) { continue; }
-        assert(names.size() != 0);
-        std::cout << names[0] << ' ';
-    }
-    std::cout << ')' << std::endl;
+    auto const unsatCore = main_solver->getUnsatCore();
+    unsatCore->print();
 }
 
 void Interpret::getInterpolants(const ASTNode& n)
@@ -1310,10 +1294,11 @@ void Interpret::getInterpolants(const ASTNode& n)
     vec<PTRef> grouping; // Consists of PTRefs that we want to group
     LetRecords letRecords;
     letRecords.pushFrame();
-    for (auto key : nameToTerm.getKeys()) {
-        letRecords.addBinding(key, nameToTerm[key]);
+    // as_const is just workaround to avoid the deprecated non-const call of getTermNames
+    auto const & termNames = std::as_const(*this).getMainSolver().getTermNames();
+    for (auto const & [name, term] : termNames) {
+        letRecords.addBinding(name, term);
     }
-
     for (auto e : exps) {
         ASTNode& c = *e;
         PTRef tr = parseTerm(c, letRecords);
@@ -1323,7 +1308,7 @@ void Interpret::getInterpolants(const ASTNode& n)
     letRecords.popFrame();
 
     if (!config.produce_inter())
-        throw OsmtApiException("Cannot interpolate");
+        throw ApiException("Cannot interpolate");
 
     assert(grouping.size() >= 2);
     std::vector<ipartitions_t> partitionings;
@@ -1336,7 +1321,7 @@ void Interpret::getInterpolants(const ASTNode& n)
         {
             int assertion_index = get_assertion_index(group);
             assert(assertion_index >= 0);
-            opensmt::setbit(p, static_cast<unsigned int>(assertion_index));
+            setbit(p, static_cast<unsigned int>(assertion_index));
         }
         else {
             bool ok = group != PTRef_Undef && logic->isAnd(group);
@@ -1348,7 +1333,7 @@ void Interpret::getInterpolants(const ASTNode& n)
                     if (!ok) { break; }
                     int assertion_index = get_assertion_index(tr);
                     assert(assertion_index >= 0);
-                    opensmt::setbit(p, static_cast<unsigned int>(assertion_index));
+                    setbit(p, static_cast<unsigned int>(assertion_index));
                 }
             }
             if (!ok) {
@@ -1390,10 +1375,12 @@ int Interpret::get_assertion_index(PTRef ref) {
     return -1;
 }
 
-void Interpret::initializeLogic(opensmt::Logic_t logicType) {
-    logic.reset(opensmt::LogicFactory::getInstance(logicType));
+void Interpret::initializeLogic(Logic_t logicType) {
+    logic.reset(LogicFactory::getInstance(logicType));
 }
 
 std::unique_ptr<MainSolver> Interpret::createMainSolver(const char* logic_name) {
     return std::make_unique<MainSolver>(*logic, config, std::string(logic_name) + " solver");
 }
+
+}
