@@ -4,10 +4,11 @@
 
 #include "FlaPartitionMap.h"
 
+namespace opensmt {
 std::vector<PTRef> FlaPartitionMap::get_top_level_flas() const {
     std::vector<PTRef> res;
     res.reserve(top_level_flas.size());
-    for(auto entry : top_level_flas) {
+    for (auto entry : top_level_flas) {
         res.push_back(entry.first);
     }
     return res;
@@ -20,19 +21,14 @@ void FlaPartitionMap::transferPartitionMembership(PTRef old, PTRef new_ptref) {
         return;
     }
     auto other_it = other_flas.find(old);
-    if (other_it != other_flas.end()) {
-        store_other_fla_index(new_ptref, other_it->second);
-    }
+    if (other_it != other_flas.end()) { store_other_fla_index(new_ptref, other_it->second); }
 }
 
 int FlaPartitionMap::getPartitionIndex(PTRef ref) const {
     auto it = top_level_flas.find(ref);
-    if (it != top_level_flas.end()) {
-        return static_cast<int>(it->second);
-    }
+    if (it != top_level_flas.end()) { return static_cast<int>(it->second); }
     auto other_it = other_flas.find(ref);
-    if (other_it != other_flas.end()) {
-        return static_cast<int>(other_it->second);
-    }
+    if (other_it != other_flas.end()) { return static_cast<int>(other_it->second); }
     return -1;
 }
+} // namespace opensmt
