@@ -5,9 +5,11 @@
  */
 
 #include "ArrayTheory.h"
-
 #include "ArrayHelpers.h"
-#include "DistinctRewriter.h"
+
+#include <rewriters/Rewritings.h>
+
+namespace opensmt {
 
 PTRef ArrayTheory::preprocessAfterSubstitutions(PTRef fla, PreprocessingContext const &) {
     // TODO: simplify select over store on the same index
@@ -15,3 +17,5 @@ PTRef ArrayTheory::preprocessAfterSubstitutions(PTRef fla, PreprocessingContext
     fla = instantiateReadOverStore(getLogic(), fla);
     return fla;
 }
+
+}
