@@ -20,10 +20,12 @@ OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWA
 #ifndef Minisat_Map_h
 #define Minisat_Map_h
 
-#include "osmtinttypes.h"
 #include "Vec.h"
+
 #include <vector>
 
+namespace opensmt {
+
 //=================================================================================================
 // Default hash/equals functions
 //
@@ -629,4 +631,6 @@ public:
 };
 
 //=================================================================================================
+}
+
 #endif
