@@ -10,27 +10,30 @@
 
 #include "Rewriter.h"
 
+namespace opensmt {
 class SubstitutionConfig : public DefaultRewriterConfig {
 public:
     using SubMap = Logic::SubstMap;
 
-private:
-    SubMap const & subMap;
-
-public:
     SubstitutionConfig(SubMap const & subMap) : subMap(subMap) {}
     PTRef rewrite(PTRef term) override {
         PTRef result;
         return subMap.peek(term, result) ? result : term;
     }
+
+private:
+    SubMap const & subMap;
 };
 
 class Substitutor : public Rewriter<SubstitutionConfig> {
-    SubstitutionConfig config;
-
 public:
     Substitutor(Logic & logic, SubstitutionConfig::SubMap const & substs)
-        : Rewriter<SubstitutionConfig>(logic, config), config(substs) {}
-};
+        : Rewriter<SubstitutionConfig>(logic, config),
+          config(substs) {}
 
-#endif // OPENSMT_SUBSTITUTOR_H
\ No newline at end of file
+private:
+    SubstitutionConfig config;
+};
+} // namespace opensmt
+
+#endif // OPENSMT_SUBSTITUTOR_H
