@@ -46,25 +46,21 @@ OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWA
 
 #include "CoreSMTSolver.h"
 
-#include "ModelBuilder.h"
-#include "OsmtInternalException.h"
-#include "Sort.h"
+#include <common/InternalException.h>
+#include <common/Random.h>
+#include <common/ReportUtils.h>
+#include <common/SystemQueries.h>
+#include <models/ModelBuilder.h>
+#include <smtsolvers/ResolutionProof.h>
 
 #include <cmath>
 #include <iostream>
 #include <iomanip>
 #include <algorithm>
 
-#include "ResolutionProof.h"
-#include "SystemQueries.h"
-#include "ReportUtils.h"
-
-#include "Random.h"
-
 namespace opensmt {
-    extern bool stop;
-}
 
+extern bool stop;
 
 //=================================================================================================
 // Constructor/Destructor:
@@ -207,7 +203,7 @@ Var CoreSMTSolver::newVar(bool dvar)
     watches  .init(mkLit(v, true));
     assigns  .push(l_Undef);
     vardata  .push(mkVarData(CRef_Undef, 0));
-    activity .push(rnd_init_act ? opensmt::drand(random_seed) * 0.00001 : 0);
+    activity .push(rnd_init_act ? drand(random_seed) * 0.00001 : 0);
     seen     .push(0);
     decision .push();
     trail    .capacity(v+1);
@@ -232,11 +228,11 @@ Var CoreSMTSolver::newVar(bool dvar)
 
 bool CoreSMTSolver::addOriginalClause_(vec<Lit> && _ps)
 {
-    opensmt::pair<CRef, CRef> fake;
+    pair<CRef, CRef> fake;
     return addOriginalClause_(std::move(_ps), fake);
 }
 
-bool CoreSMTSolver::addOriginalClause_(vec<Lit> && ps, opensmt::pair<CRef, CRef> & inOutCRefs)
+bool CoreSMTSolver::addOriginalClause_(vec<Lit> && ps, pair<CRef, CRef> & inOutCRefs)
 {
     assert(decisionLevel() == 0);
     inOutCRefs = {CRef_Undef, CRef_Undef};
@@ -512,7 +508,7 @@ void CoreSMTSolver::cancelUntilVarTempDone( )
 Var CoreSMTSolver::doRandomDecision() {
     Var next = var_Undef;
     if (branchLitRandom()) {
-        next = order_heap[opensmt::irand(random_seed,order_heap.size())];
+        next = order_heap[irand(random_seed,order_heap.size())];
         if (value(next) == l_Undef && decision[next])
             rnd_decisions++;
     }
@@ -520,7 +516,7 @@ Var CoreSMTSolver::doRandomDecision() {
 }
 
 bool CoreSMTSolver::branchLitRandom() {
-    return opensmt::drand(random_seed) < random_var_freq && !order_heap.empty();
+    return drand(random_seed) < random_var_freq && !order_heap.empty();
 }
 
 Var CoreSMTSolver::doActivityDecision() {
@@ -682,7 +678,7 @@ void CoreSMTSolver::analyze(CRef confl, vec<Lit>& out_learnt, int& out_btlevel)
             }
             else
             {
-                ctr = config.sat_temporary_learn ? ca.alloc(r, {true, computeGlue(r)}) : ca.alloc(r);
+                ctr = config.sat_temporary_learn ? ca.alloc(r, true, computeGlue(r)) : ca.alloc(r);
                 learnts.push(ctr);
                 attachClause(ctr);
                 undo_stack.push(undo_stack_el(undo_stack_el::NEWLEARNT, ctr));
@@ -860,7 +856,7 @@ bool CoreSMTSolver::litRedundant(Lit p, uint32_t abstract_levels)
             }
             else
             {
-                ct = config.sat_temporary_learn ? ca.alloc(r, {true, computeGlue(r)}) : ca.alloc(r);
+                ct = config.sat_temporary_learn ? ca.alloc(r, true, computeGlue(r)) : ca.alloc(r);
                 learnts.push(ct);
                 if (config.isIncremental() != 0)
                     undo_stack.push(undo_stack_el(undo_stack_el::NEWLEARNT, ct));
@@ -1329,7 +1325,7 @@ void CoreSMTSolver::popBacktrackPoint()
         }
         else
         {
-            throw OsmtInternalException("unknown undo operation in CoreSMTSolver" + std::to_string(op.getType()));
+            throw InternalException("unknown undo operation in CoreSMTSolver" + std::to_string(op.getType()));
         }
 
         undo_stack.pop();
@@ -1390,7 +1386,7 @@ void CoreSMTSolver::learntSizeAdjust() {
 lbool CoreSMTSolver::search(int nof_conflicts)
 {
     // Time my executionto search_timer
-//    opensmt::StopWatch stopwatch = opensmt::StopWatch(search_timer);
+//    StopWatch stopwatch = StopWatch(search_timer);
 #ifdef VERBOSE_SAT
     cerr << "Units when starting search:" << endl;
     for (int i = 2; i < trail.size(); i++)
@@ -1477,7 +1473,7 @@ lbool CoreSMTSolver::search(int nof_conflicts)
                 learnts_size += learnt_clause.size( );
                 all_learnts ++;
 
-                CRef cr = ca.alloc(learnt_clause, {true, computeGlue(learnt_clause)});
+                CRef cr = ca.alloc(learnt_clause, true, computeGlue(learnt_clause));
 
                 if (logsResolutionProof()) {
                     resolutionProof->endChain(cr);
@@ -1670,7 +1666,7 @@ void CoreSMTSolver::declareVarsToTheories()
 
 lbool CoreSMTSolver::solve_()
 {
-//    opensmt::PrintStopWatch watch("solve time", cerr);
+//    PrintStopWatch watch("solve time", cerr);
 
     for (Lit l : this->assumptions) {
         this->addVar_(var(l));
@@ -1906,27 +1902,4 @@ void CoreSMTSolver::fillBooleanVars(ModelBuilder &modelBuilder) {
     }
 }
 
-vec<CRef> CoreSMTSolver::getUnsatCoreClauses() const {
-    assert(resolutionProof);
-    vec<CRef> unsatCore;
-    auto const & derivations = resolutionProof->getProof();
-    std::vector<CRef> stack;
-    stack.push_back(CRef_Undef);
-    std::unordered_set<CRef> processed;
-    while (not stack.empty()) {
-        CRef current = stack.back();
-        stack.pop_back();
-        if (auto [_, inserted] = processed.insert(current); not inserted) { continue; }
-        auto it = derivations.find(current);
-        assert(it != derivations.end());
-        auto const & derivation = it->second;
-        if (derivation.type == clause_type::CLA_ORIG) {
-            unsatCore.push(current);
-            continue;
-        }
-        if (derivation.type == clause_type::CLA_LEARNT) {
-            for (CRef premise : derivation.chain_cla) { stack.push_back(premise); }
-        }
-    }
-    return unsatCore;
 }
