@@ -46,22 +46,21 @@ OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWA
 #ifndef MINISATSMTSOLVER_H
 #define MINISATSMTSOLVER_H
 
-#include "THandler.h"
+#include <common/Timer.h>
+#include <common/TypeUtils.h>
+#include <minisat/core/SolverTypes.h>
+#include <minisat/mtl/Vec.h>
+#include <minisat/mtl/Heap.h>
+#include <minisat/mtl/Alg.h>
+#include <tsolvers/THandler.h>
 
 #include <cstdio>
 #include <iosfwd>
 #include <memory>
 #include <sstream>
-
 #include <vector>
 
-#include "Vec.h"
-#include "Heap.h"
-#include "Alg.h"
-
-#include "SolverTypes.h"
-
-#include "Timer.h"
+namespace opensmt {
 
 class ResolutionProof;
 class ModelBuilder;
@@ -70,11 +69,6 @@ class ModelBuilder;
 std::ostream& operator <<(std::ostream& out, Lit l); // MB: Feel free to find a better place for this method.
 
 
-template<class A, class B>
-struct Pair { A first; B second; };
-
-
-
 //=================================================================================================
 // Solver -- the main class:
 
@@ -112,7 +106,7 @@ public:
     bool    addOriginalClause(Lit p, Lit q, Lit r);                    // Add a ternary clause to the solver.
 protected:
     bool addOriginalClause_(vec<Lit> && _ps);                                          // Add a clause to the solver
-    bool addOriginalClause_(vec<Lit> && _ps, opensmt::pair<CRef, CRef> & inOutCRefs);  // Add a clause to the solver and return the references for the added class before and after simplification
+    bool addOriginalClause_(vec<Lit> && _ps, pair<CRef, CRef> & inOutCRefs);  // Add a clause to the solver and return the references for the added class before and after simplification
 public:
     // Solving:
     //
@@ -151,7 +145,6 @@ public:
     void fillBooleanVars(ModelBuilder & modelBuilder);
 
     ResolutionProof const & getResolutionProof() const { assert(resolutionProof); return *resolutionProof; }
-    vec<CRef> getUnsatCoreClauses() const;
 
     // Resource contraints:
     //
@@ -215,8 +208,8 @@ public:
     uint64_t solves, starts, decisions, rnd_decisions, propagations, conflicts, conflicts_last_update;
     uint64_t dec_vars, clauses_literals, learnts_literals, max_literals, tot_literals;
 #ifdef STATISTICS
-    opensmt::OSMTTimeVal search_timer;
-    opensmt::OSMTTimeVal branchTimer;
+    TimeVal search_timer;
+    TimeVal branchTimer;
 #endif
     double learnts_size;
     uint64_t all_learnts;
@@ -958,4 +951,6 @@ inline void CoreSMTSolver::printClause( vec< Lit > & c )
     }
 }
 
+}
+
 #endif
