@@ -46,12 +46,13 @@ OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWA
 
 #include "SimpSMTSolver.h"
 
-#include "ReportUtils.h"
-#include "Sort.h"
+#include <common/ReportUtils.h>
 
 //=================================================================================================
 // Constructor/Destructor:
 
+namespace opensmt {
+
 SimpSMTSolver::SimpSMTSolver(SMTConfig & c, THandler & t) :
     CoreSMTSolver(c, t)
     , grow               (c.sat_grow())
@@ -123,7 +124,7 @@ lbool SimpSMTSolver::solve_(bool do_simp, bool turn_off_simp)
     lbool    result = l_True;
 
     if (config.sat_preprocess_theory != 0) {
-        throw OsmtApiException("preprocess theory has been temporairly disabled in this version");
+        throw ApiException("preprocess theory has been temporairly disabled in this version");
     }
 
     // Added Code
@@ -180,7 +181,7 @@ lbool SimpSMTSolver::solve_(bool do_simp, bool turn_off_simp)
 //=================================================================================================
 // Added code
 
-bool SimpSMTSolver::addOriginalSMTClause(vec<Lit> && smt_clause, opensmt::pair<CRef, CRef> & inOutCRefs)
+bool SimpSMTSolver::addOriginalSMTClause(vec<Lit> && smt_clause, pair<CRef, CRef> & inOutCRefs)
 {
     inOutCRefs = {CRef_Undef, CRef_Undef};
     assert( config.sat_preprocess_theory == 0 );
@@ -617,7 +618,7 @@ bool SimpSMTSolver::eliminateVar(Var v)
     for (int i = 0; i < pos.size(); i++) {
         for (int j = 0; j < neg.size(); j++) {
             vec<Lit> resolvent;
-            opensmt::pair<CRef,CRef> dummy {CRef_Undef, CRef_Undef};
+            pair<CRef,CRef> dummy {CRef_Undef, CRef_Undef};
             if (merge(ca[pos[i]], ca[neg[j]], v, resolvent) && !addOriginalSMTClause(std::move(resolvent), dummy))
                 return false;
         }
@@ -659,7 +660,7 @@ bool SimpSMTSolver::substitute(Var v, Lit x)
 
         removeClause(cls[i]);
 
-        opensmt::pair<CRef,CRef> dummy {CRef_Undef, CRef_Undef};
+        pair<CRef,CRef> dummy {CRef_Undef, CRef_Undef};
         if (!addOriginalSMTClause(std::move(subst_clause), dummy))
             return ok = false;
     }
@@ -861,3 +862,5 @@ void SimpSMTSolver::garbageCollect()
 //               ca.size()*ClauseAllocator::Unit_Size, to.size()*ClauseAllocator::Unit_Size);
     to.moveTo(ca);
 }
+
+}
