@@ -1,7 +1,10 @@
 #include "UFTHandler.h"
-#include "TreeOps.h"
-#include "Egraph.h"
-#include "InterpolatingEgraph.h"
+#include "egraph/Egraph.h"
+#include "egraph/InterpolatingEgraph.h"
+
+#include <common/TreeOps.h>
+
+namespace opensmt {
 
 UFTHandler::UFTHandler(SMTConfig & c, Logic & l)
     : TSolverHandler(c)
@@ -33,3 +36,5 @@ PTRef UFTHandler::getInterpolant(const ipartitions_t& mask, ItpColorMap * labels
     assert(iegraph);
     return iegraph->getInterpolant(mask, labels, pmanager);
 }
+
+}
