@@ -7,10 +7,12 @@
 
 #include "ArraySolver.h"
 
-#include "TreeOps.h"
+#include <common/TreeOps.h>
 
 #include <numeric>
 
+namespace opensmt {
+
 static SolverDescr descr_ax_solver("Array Solver", "Solver for Theory of Arrays");
 
 ArraySolver::ArraySolver(Logic & logic, Egraph & egraph, SMTConfig & config) :
@@ -317,7 +319,7 @@ TRes ArraySolver::checkExtensionality() {
 
     std::unordered_map<NodeRef, ExtensionalityInfo, NodeRefHash> extensionalityInfos;
     std::unordered_map<ExtensionalityInfo, NodeRef, ExtensionalityInfoHash> inverseExtensionalityInfos;
-    vec<opensmt::pair<NodeRef, NodeRef>> equalitiesToPropagate;
+    vec<pair<NodeRef, NodeRef>> equalitiesToPropagate;
 
     vec<NodeRef> queue;
     queue.capacity(rootsMap.size());
@@ -592,6 +594,7 @@ ArraySolver::ExplanationCollection ArraySolver::explainWeakEquivalencePath(ERef
 
 void ArraySolver::clear() {
     lemmas.clear();
+    splitondemand.clear();
     selectsInfo.clear();
     nodes.clear();
     rootsMap.clear();
@@ -794,3 +797,5 @@ void ArraySolver::ExplanationCursor::collectOnePrimary(IndicesCollection & indic
     indices.insert(traversal.getSolver().getIndexFromStore(store)); // MB: This must be the real index, not its root!
     currentNode = {traversal.getNode(currentNode.ref).primaryEdge, target};
 }
+
+}
