@@ -59,10 +59,12 @@ The algorithm and data structures are inspired by the following paper:
 #include "Egraph.h"
 #include "EgraphModelBuilder.h"
 #include "Enode.h"
-#include "TreeOps.h"
-#include "Deductions.h"
-#include "ModelBuilder.h"
 
+#include <common/TreeOps.h>
+#include <tsolvers/Deductions.h>
+#include <models/ModelBuilder.h>
+
+namespace opensmt {
 
 static SolverDescr descr_uf_solver("UF Solver", "Solver for Quantifier Free Theory of Uninterpreted Functions with Equalities");
 
@@ -112,7 +114,7 @@ void Egraph::pushBacktrackPoint( )
 // Pops a backtrack point
 //
 void Egraph::popBacktrackPoint() {
-//    opensmt::StopWatch sw(egraphStats.egraph_backtrack_timer);
+//    StopWatch sw(egraphStats.egraph_backtrack_timer);
     assert( backtrack_points.size( ) > 0 );
     size_t undo_stack_new_size = backtrack_points.last();
     backtrack_points.pop();
@@ -749,7 +751,7 @@ void Egraph::backtrackToStackSize ( size_t size ) {
             }
             default: {
                 assert(false);
-                throw OsmtInternalException("unknown action");
+                throw InternalException("unknown action");
                 break;
             }
         }
@@ -1145,7 +1147,7 @@ bool Egraph::assertLit(PtAsgn pta)
         res = addDisequality(PtAsgn(pt_r, l_True));
     } else if (isEffectivelyDisequality(pt_r) && sgn == l_False) {
         if (logic.getPterm(pt_r).size() != 2) {
-            throw OsmtInternalException("Internal error: Negated distinct asserted to Egraph");
+            throw InternalException("Internal error: Negated distinct asserted to Egraph");
         }
         res = addEquality(PtAsgn(pt_r, l_False));
     } else if (isEffectivelyUP(pt_r) && sgn == l_True) {
@@ -1528,7 +1530,7 @@ bool Egraph::childDuplicatesClass(ERef parent, uint32_t childIndex) {
     Enode const & parentNode = getEnode(parent);
     ERef child = parentNode[childIndex];
     auto childClass = getEnode(getEnode(child).getRoot()).getCid();
-    auto precedingChildren = opensmt::span(parentNode.begin(), childIndex);
+    auto precedingChildren = span(parentNode.begin(), childIndex);
     return std::any_of(precedingChildren.begin(), precedingChildren.end(), [&](ERef precChild) {
        return childClass == getEnode(getEnode(precChild).getRoot()).getCid();
     });
@@ -1642,3 +1644,5 @@ vec<PTRef> Egraph::collectEqualitiesFor(vec<PTRef> const & vars, std::unordered_
     }
     return equalities;
 }
+
+}
