@@ -5,10 +5,13 @@
 #ifndef OPENSMT_INTERPOLATINGEGRAPH_H
 #define OPENSMT_INTERPOLATINGEGRAPH_H
 
-#include <PartitionManager.h>
 #include "Egraph.h"
 #include "UFInterpolator.h"
 
+#include <api/PartitionManager.h>
+
+namespace opensmt {
+
 class InterpolatingEgraph : public Egraph {
 public:
     InterpolatingEgraph(SMTConfig & c, Logic & l) : Egraph{c, l, Egraph::ExplainerType::INTERPOLATING}
@@ -23,4 +26,6 @@ public:
     }
 };
 
+}
+
 #endif //OPENSMT_INTERPOLATINGEGRAPH_H
