@@ -7,6 +7,7 @@
 
 #include "CutCreator.h"
 
+namespace opensmt {
 CutCreator::Cut CutCreator::makeCut(SparseLinearSystem && system, ColumnMapping const & columnMapping) {
     auto & matrixA = system.A;
 
@@ -16,21 +17,19 @@ CutCreator::Cut CutCreator::makeCut(SparseLinearSystem && system, ColumnMapping
     auto [matrixU, dim] = HermiteNormalForm()(std::move(matrixA));
 
     // Get the values of the variables
-    std::vector<opensmt::Real> varValues;
+    std::vector<Real> varValues;
     varValues.reserve(varCount);
     for (uint32_t col = 0; col < varCount; ++col) {
         PTRef var = columnMapping[col];
         varValues.push_back(evaluate(var));
     }
-    // Now check every row of U for infeasibility: if the cross product of the row and vector of variable values is not
-    // an integer, the row represents an infeasible constraint
+    // Now check every row of U for infeasibility: if the cross product of the row and vector of variable values is
+    // not an integer, the row represents an infeasible constraint
     for (uint32_t rowIndex = 0; rowIndex < dim; ++rowIndex) {
         auto const & row = matrixU[rowIndex];
         auto product = row.product(varValues);
-        if (not product.isInteger()) {
-            return {row.toVector(), product};
-        }
+        if (not product.isInteger()) { return {row.toVector(), product}; }
     }
     return {};
 }
-
+} // namespace opensmt
