@@ -9,26 +9,26 @@
 #ifndef OPENSMT_CUTCREATOR_H
 #define OPENSMT_CUTCREATOR_H
 
-#include "Real.h"
-#include "Polynomial.h"
 #include "SparseMatrix.h"
-#include "PTRef.h"
-#include "TypeUtils.h"
 
+#include <common/TypeUtils.h>
+#include <common/numbers/Real.h>
+#include <pterms/PTRef.h>
+
+namespace opensmt {
 class CutCreator {
-private:
-    std::function<FastRational(PTRef)> varValue;
-
-    FastRational evaluate(PTRef var) const { return varValue(var); }
 public:
+    explicit CutCreator(std::function<Real(PTRef)> && varValue) : varValue(std::move(varValue)) {}
 
-
-    explicit CutCreator(std::function<FastRational(PTRef)> && varValue) : varValue(std::move(varValue)) {}
-
-    using Cut = opensmt::pair<SparseColMatrix::TermVec, FastRational>;
+    using Cut = pair<SparseColMatrix::TermVec, Real>;
     using ColumnMapping = std::vector<PTRef>;
     Cut makeCut(SparseLinearSystem && constraints, ColumnMapping const &);
+
+private:
+    Real evaluate(PTRef var) const { return varValue(var); }
+
+    std::function<Real(PTRef)> varValue;
 };
+} // namespace opensmt
 
-
-#endif //OPENSMT_CUTCREATOR_H
+#endif // OPENSMT_CUTCREATOR_H
