@@ -1,21 +1,22 @@
 /*
  *  Copyright (c) 2019-2022, Antti Hyvarinen <antti.hyvarinen@gmail.com>
- *  Copyright (c) 2019-2022, Martin Blicha <martin.blicha@gmail.com>
+ *  Copyright (c) 2019-2025, Martin Blicha <martin.blicha@gmail.com>
  *
  *  SPDX-License-Identifier: MIT
  */
 
 #include "LASolver.h"
-
 #include "FarkasInterpolator.h"
-#include "LA.h"
-#include "ModelBuilder.h"
 #include "LIAInterpolator.h"
 #include "CutCreator.h"
-#include "Random.h"
+
+#include <common/Random.h>
+#include <models/ModelBuilder.h>
 
 #include <unordered_set>
 
+namespace opensmt {
+
 static SolverDescr descr_la_solver("LA Solver", "Solver for Quantifier Free Linear Arithmetics");
 
 
@@ -23,59 +24,33 @@ PtAsgn LASolver::getAsgnByBound(LABoundRef br) const {
     return LABoundRefToLeqAsgn[boundStore[br].getId()];
 }
 
-LABoundStore::BoundInfo LASolver::addBound(PTRef leq_tr) {
-    auto [const_tr, sum_tr] = logic.leqToConstantAndTerm(leq_tr);
-    assert(logic.isNumConst(const_tr) && logic.isLinearTerm(sum_tr));
+void LASolver::addBound(PTRef leq_tr) {
+    LABoundRefPair boundRefs = [this, leq_tr]() -> LABoundRefPair {
+        auto [const_tr, sum_tr] = logic.leqToConstantAndTerm(leq_tr);
+        assert(logic.isNumConst(const_tr) && logic.isLinearTerm(sum_tr));
+        LVRef const v = getVarForTerm(sum_tr);
+        bool const isNegated = laVarMapper.isNegated(sum_tr);
+        auto values = isNegated ? getBoundsValue(v, -logic.getNumConst(const_tr), false)
+            : getBoundsValue(v, logic.getNumConst(const_tr), true);
+        auto const bi = status == INIT ? boundStore.allocBoundPair(v, std::move(values)) : boundStore.allocBoundPairAndSort(v, std::move(values));
+        return isNegated ? LABoundRefPair{bi.ub, bi.lb} : LABoundRefPair{bi.lb, bi.ub};
+    }();
 
-    bool sum_term_is_negated = laVarMapper.isNegated(sum_tr);
-
-    LVRef v = laVarMapper.getVarByPTId(logic.getPterm(sum_tr).getId());
-
-    LABoundStore::BoundInfo bi;
-    LABoundRef br_pos;
-    LABoundRef br_neg;
-
-    if (sum_term_is_negated) {
-        opensmt::Real constr_neg = -logic.getNumConst(const_tr);
-        bi = boundStore.allocBoundPair(v, this->getBoundsValue(v, constr_neg, false));
-        br_pos = bi.ub;
-        br_neg = bi.lb;
-    }
-    else {
-        const Real& constr = logic.getNumConst(const_tr);
-        bi = boundStore.allocBoundPair(v, this->getBoundsValue(v, constr, true));
-        br_pos = bi.lb;
-        br_neg = bi.ub;
-    }
-    int br_pos_idx = boundStore[br_pos].getId();
-    int br_neg_idx = boundStore[br_neg].getId();
-
-    int tid = Idx(logic.getPterm(leq_tr).getId());
+    int const tid = Idx(logic.getPterm(leq_tr).getId());
+    // Must be a new inequality
+    assert(tid >= LeqToLABoundRefPair.size() or (LeqToLABoundRefPair[tid] == LABoundRefPair{LABoundRef_Undef, LABoundRef_Undef}));
     if (LeqToLABoundRefPair.size() <= tid) {
         LeqToLABoundRefPair.growTo(tid + 1);
     }
-    LeqToLABoundRefPair[tid] = LABoundRefPair{br_pos, br_neg};
+    LeqToLABoundRefPair[tid] = boundRefs;
 
+    int const br_pos_idx = boundStore[boundRefs.pos].getId();
+    int const br_neg_idx = boundStore[boundRefs.neg].getId();
     if (LABoundRefToLeqAsgn.size() <= std::max(br_pos_idx, br_neg_idx)) {
         LABoundRefToLeqAsgn.growTo(std::max(br_pos_idx, br_neg_idx) + 1);
     }
     LABoundRefToLeqAsgn[br_pos_idx] = PtAsgn(leq_tr, l_True);
     LABoundRefToLeqAsgn[br_neg_idx] = PtAsgn(leq_tr, l_False);
-    return bi;
-}
-
-void LASolver::updateBound(PTRef tr)
-{
-    // If the bound already exists, do nothing.
-    int id = Idx(logic.getPterm(tr).getId());
-
-    if ((LeqToLABoundRefPair.size() > id) &&
-        !(LeqToLABoundRefPair[id] == LABoundRefPair{LABoundRef_Undef, LABoundRef_Undef})) {
-        return;
-    }
-
-    LABoundStore::BoundInfo bi = addBound(tr);
-    boundStore.updateBound(bi);
 }
 
 bool LASolver::isValid(PTRef tr)
@@ -151,7 +126,7 @@ void LASolver::storeExplanation(Simplex::Explanation &&explanationBounds) {
 }
 
 bool LASolver::check_simplex(bool complete) {
-    // opensmt::StopWatch check_timer(egraphStats.simplex_timer);
+    // StopWatch check_timer(egraphStats.simplex_timer);
 //    printf(" - check %d\n", debug_check_count++);
     (void)complete;
     // check if we stop reading constraints
@@ -174,50 +149,8 @@ bool LASolver::check_simplex(bool complete) {
     return getStatus();
 }
 
-//
-// The model system
-//
-/*
-bool LASolver::isModelOutOfBounds(LVRef v) const {
-    return simplex.isModelOutOfBounds(v);
-}
 
-bool LASolver::isModelOutOfUpperBound(LVRef v) const
-{
-    return simplex.isModelOutOfBounds(v);
-}
-
-bool LASolver::isModelOutOfLowerBound(LVRef v) const
-{
-    return ( model.read(v) < model.Lb(v) );
-}
-
-
-const Delta LASolver::overBound(LVRef v) const
-{
-    assert( isModelOutOfBounds(v) );
-    if (isModelOutOfUpperBound(v))
-    {
-        return ( Delta(model.read(v) - model.Ub(v)) );
-    }
-    else if ( isModelOutOfLowerBound(v) )
-    {
-        return ( Delta(model.Lb(v) - model.read(v)) );
-    }
-    assert (false);
-    printf("Problem in overBound, LRASolver.C:%d\n", __LINE__);
-    exit(1);
-}
-*/
-
-void LASolver::setBound(PTRef leq_tr)
-{
-//    printf("Setting bound for %s\n", logic.printTerm(leq_tr));
-
-    addBound(leq_tr);
-}
-
-opensmt::Number LASolver::getNum(PTRef r) {
+Number LASolver::getNum(PTRef r) {
     return logic.getNumConst(r);
 }
 
@@ -238,15 +171,12 @@ void LASolver::markVarAsInt(LVRef v) {
 LVRef LASolver::getVarForLeq(PTRef ref) const {
     assert(logic.isLeq(ref));
     auto [constant, term] = logic.leqToConstantAndTerm(ref);
-    return laVarMapper.getVarByPTId(logic.getPterm(term).getId());
+    return getVarForTerm(term);
 }
 
 LVRef LASolver::getLAVar_single(PTRef expr_in) {
-
     assert(logic.isLinearTerm(expr_in));
-    PTId id = logic.getPterm(expr_in).getId();
-
-    if (laVarMapper.hasVar(id)) {
+    if (laVarMapper.hasVar(expr_in)) {
         return getVarForTerm(expr_in);
     }
 
@@ -337,19 +267,17 @@ void LASolver::declareAtom(PTRef leq_tr)
 
     if (status != INIT)
     {
-        // Treat the PTRef as it is pushed on-the-fly
-        //    status = INCREMENT;
-        assert( status == SAT );
+        assert(status == SAT);
         PTRef term = logic.getPterm(leq_tr)[1];
         registerArithmeticTerm(term);
-        updateBound(leq_tr);
+        addBound(leq_tr);
     }
     // DEBUG check
     isProperLeq(leq_tr);
 }
 
 LVRef LASolver::splitOnRandom(vec<LVRef> const & varsToFix) {
-    int pick = opensmt::irand(seed, varsToFix.size());
+    int pick = irand(seed, varsToFix.size());
     return varsToFix[pick];
 }
 
@@ -558,16 +486,16 @@ void LASolver::initSolver()
             registerArithmeticTerm(term);
 
             // Assumes that the LRA variable has been already declared
-            setBound(leq_tr);
+            addBound(leq_tr);
         }
-        boundStore.buildBounds(); // Bounds are needed for gaussian elimination
+        boundStore.buildBounds();
 
         simplex.initModel();
 
         status = SAT;
     }
     else {
-        throw OsmtInternalException("Solver can not be initialized in the state different from INIT");
+        throw InternalException("Solver can not be initialized in the state different from INIT");
     }
 }
 
@@ -599,7 +527,7 @@ inline bool LASolver::getStatus( )
         case INIT:
         case ERROR:
         default:
-            throw OsmtApiException("Status is undef!");
+            throw ApiException("Status is undef!");
     }
 }
 
@@ -665,7 +593,7 @@ void LASolver::fillTheoryFunctions(ModelBuilder & modelBuilder) const {
 }
 
 
-void LASolver::computeConcreteModel(LVRef v, const opensmt::Real& delta) {
+void LASolver::computeConcreteModel(LVRef v, const Real& delta) {
     while (concrete_model.size() <= getVarId(v))
         concrete_model.push_back(0);
     Delta val = simplex.getValuation(v);
@@ -680,7 +608,7 @@ void LASolver::computeConcreteModel(LVRef v, const opensmt::Real& delta) {
 void LASolver::computeModel()
 {
     assert( status == SAT );
-    opensmt::Real delta = simplex.computeDelta();
+    Real delta = simplex.computeDelta();
 
     for (LVRef var : laVarStore)
     {
@@ -774,7 +702,7 @@ PTRef LASolver::interpolateUsingEngine(FarkasInterpolator & interpolator) const
     auto itpAlgorithm = config.getLRAInterpolationAlgorithm();
     if (itpAlgorithm == itp_lra_alg_strong) { return interpolator.getFarkasInterpolant(); }
     else if (itpAlgorithm == itp_lra_alg_weak) { return interpolator.getDualFarkasInterpolant(); }
-    else if (itpAlgorithm == itp_lra_alg_factor) { return interpolator.getFlexibleInterpolant(opensmt::Real(config.getLRAStrengthFactor())); }
+    else if (itpAlgorithm == itp_lra_alg_factor) { assert(not logic.hasIntegers()); return interpolator.getFlexibleInterpolant(Real(config.getLRAStrengthFactor())); }
     else if (itpAlgorithm == itp_lra_alg_decomposing_strong) { return interpolator.getDecomposedInterpolant(); }
     else if (itpAlgorithm == itp_lra_alg_decomposing_weak) { return interpolator.getDualDecomposedInterpolant(); }
     else {
@@ -817,7 +745,7 @@ namespace {
 
 struct DefiningConstraint {
     PTRef lhs;
-    opensmt::Real rhs;
+    Real rhs;
 };
 
 /*
@@ -855,7 +783,7 @@ std::pair<SparseLinearSystem,std::vector<PTRef>> linearSystemFromConstraints(std
 
     uint32_t rows = constraints.size();
     SparseColMatrix matrixA(RowCount{rows}, ColumnCount{columns});
-    std::vector<FastRational> rhs(rows);
+    std::vector<Number> rhs(rows);
     std::vector<SparseColMatrix::ColumnPolynomial> columnPolynomials(columns);
 
     // Second pass to build the actual matrix
@@ -933,7 +861,7 @@ TRes LASolver::cutFromProof() {
     }
     auto getVarValue = [this](PTRef var) {
         assert(this->logic.isVar(var));
-        LVRef lvar = this->laVarMapper.getVarByPTId(logic.getPterm(var).getId());
+        LVRef lvar = this->getVarForTerm(var);
         Delta val = this->simplex.getValuation(lvar);
         assert(not val.hasDelta());
         return val.R();
@@ -953,7 +881,7 @@ TRes LASolver::cutFromProof() {
 vec<PTRef> LASolver::collectEqualitiesFor(vec<PTRef> const & vars, std::unordered_set<PTRef, PTRefHash> const & knownEqualities) {
     struct DeltaHash {
         std::size_t operator()(Delta const & d) const {
-            FastRationalHash hasher;
+            NumberHash hasher;
             return (hasher(d.R()) ^ hasher(d.D()));
         }
     };
@@ -968,7 +896,7 @@ vec<PTRef> LASolver::collectEqualitiesFor(vec<PTRef> const & vars, std::unordere
             if (not laVarMapper.hasVar(var)) { // LASolver does not have any constraints on this LA var
                 continue;
             }
-            LVRef v = laVarMapper.getVarByPTId(logic.getPterm(var).getId());
+            LVRef v = getVarForTerm(var);
             auto value = simplex.getValuation(v);
             eqClasses[value].push(var);
         }
@@ -1004,7 +932,7 @@ vec<PTRef> LASolver::collectEqualitiesFor(vec<PTRef> const & vars, std::unordere
                 if (isNonPositive(diff.R()) and isNegative(diff.D())) { continue; }
                 auto ratio = diff.R() / diff.D();
                 assert(isNegative(ratio));
-                if (ratio < FastRational(-1)) { continue; } // MB: ratio is -delta; hence -1 <= ratio < 0
+                if (ratio < Number(-1)) { continue; } // MB: ratio is -delta; hence -1 <= ratio < 0
 
                 // They could be equal for the right value of delta, add equalities for cross-product
                 vec<PTRef> const & varsOfFirstVal = eqClasses.at(val);
@@ -1025,3 +953,5 @@ vec<PTRef> LASolver::collectEqualitiesFor(vec<PTRef> const & vars, std::unordere
     }
     return equalities;
 }
+
+}
