@@ -1,18 +1,20 @@
 #ifndef OPENSMT_IDLSOLVER_H
 #define OPENSMT_IDLSOLVER_H
 
+#include "Converter.h"
 #include "STPSolver.h"
 #include "SafeInt.h"
-#include "Converter.h"
-#include "ModelBuilder.h"
 
+#include <models/ModelBuilder.h>
+
+namespace opensmt {
 class IDLSolver : public STPSolver<SafeInt> {
 public:
-    IDLSolver(SMTConfig &c, ArithLogic &l) : STPSolver(c, l) {};
+    IDLSolver(SMTConfig & c, ArithLogic & l) : STPSolver(c, l) {};
 };
 
 template<>
-SafeInt Converter<SafeInt>::getValue(const FastRational &val) {
+SafeInt Converter<SafeInt>::getValue(Number const & val) {
     assert(val.isInteger());
     return SafeInt(static_cast<ptrdiff_t>(val.get_d()));
 }
@@ -23,12 +25,12 @@ SafeInt Converter<SafeInt>::getValue(ptrdiff_t val) {
 }
 
 template<>
-SafeInt Converter<SafeInt>::negate(const SafeInt &val) {
+SafeInt Converter<SafeInt>::negate(SafeInt const & val) {
     return SafeInt(-(val.value() + 1));
 }
 
 template<>
-std::string Converter<SafeInt>::show(const SafeInt &val) {
+std::string Converter<SafeInt>::show(SafeInt const & val) {
     return std::to_string(val.value());
 }
 
@@ -44,6 +46,6 @@ void STPSolver<SafeInt>::fillTheoryFunctions(ModelBuilder & modelBuilder) const
         modelBuilder.addVarValue(var, val);
     }
 }
+} // namespace opensmt
 
-
-#endif //OPENSMT_IDLSOLVER_H
+#endif // OPENSMT_IDLSOLVER_H
