@@ -6,14 +6,26 @@
 #include <unordered_map>
 // implementations of template functions #included below class definition
 
+namespace opensmt {
 // holds the mapping from vertices to their values
 template<class T>
 class STPModel {
-private:
-    STPStore<T> &store;
-    EdgeGraph graph;
-    std::unordered_map<uint32_t, T> valMap;  // for each vertex, distance from the added starting vertex
+public:
+    STPModel(STPStore<T> & store, EdgeGraph graph) : store(store), graph(std::move(graph)) {}
 
+    void createModel();
+
+    bool hasValue(VertexRef v) const { return valMap.count(v.x); }
+
+    T getValue(VertexRef v) const {
+        return Converter<T>::getValue(0) - valMap.at(v.x);
+    } // valid assignment is actually the inverse of distance
+
+    std::unordered_map<VertexRef, T, VertexRefHash> getAllValues() const;
+
+    EdgeGraph const & getGraph() const { return graph; }
+
+private:
     std::vector<VertexRef> vertsInGraph() const;
 
     VertexRef addStartingPoint();
@@ -22,20 +34,12 @@ private:
 
     void shiftZero();
 
-public:
-    STPModel(STPStore<T> &store, EdgeGraph graph) : store(store), graph(std::move(graph)) {}
-
-    void createModel();
-
-    bool hasValue(VertexRef v) const { return valMap.count(v.x); }
-
-    T getValue(VertexRef v) const { return Converter<T>::getValue(0) - valMap.at(v.x); } // valid assignment is actually the inverse of distance
-
-    std::unordered_map<VertexRef, T, VertexRefHash> getAllValues() const;
-
-    EdgeGraph const & getGraph() const { return graph; }
+    STPStore<T> & store;
+    EdgeGraph graph;
+    std::unordered_map<uint32_t, T> valMap; // for each vertex, distance from the added starting vertex
 };
+} // namespace opensmt
 
 #include "STPModel_implementations.hpp"
 
-#endif //OPENSMT_STPVALMAPPER_HPP
+#endif // OPENSMT_STPVALMAPPER_HPP
