@@ -2,7 +2,9 @@
 // Created by Antti on 31.03.20.
 //
 #include <gtest/gtest.h>
-#include <LABounds.h>
+#include <tsolvers/lasolver/LABounds.h>
+
+namespace opensmt {
 
 class BoundTest: public ::testing::Test {
 public:
@@ -29,3 +31,5 @@ TEST_F(BoundTest, test_LABounds) {
         bs.clear();
     }
 }
+
+}
