@@ -2,17 +2,15 @@
 // Created by prova on 30.09.20.
 //
 #include <gtest/gtest.h>
-#include <Real.h>
-#include <stdlib.h>
-#include <Vec.h>
-#include <Sort.h>
-#include <SMTConfig.h>
-#include <ArithLogic.h>
+#include <common/numbers/Real.h>
+#include <logics/ArithLogic.h>
+
+namespace opensmt {
 
 class LIAStrengthening: public ::testing::Test {
 public:
     ArithLogic logic;
-    LIAStrengthening() : logic{opensmt::Logic_t::QF_LIA} {}
+    LIAStrengthening() : logic{Logic_t::QF_LIA} {}
 };
 
 TEST_F(LIAStrengthening, test_LIAStrengthening) {
@@ -25,3 +23,5 @@ TEST_F(LIAStrengthening, test_LIAStrengthening) {
     ASSERT_EQ(logic.getConstantFromLeq(ineq), logic.mkConst("2"));
     ASSERT_EQ(logic.getTermFromLeq(ineq), logic.mkPlus(x,y));
 }
+
+}
