@@ -5,8 +5,9 @@
  */
 
 #include <gtest/gtest.h>
-#include "SolverTypes.h"
-#include <numeric>
+#include <minisat/core/SolverTypes.h>
+
+namespace opensmt {
 
 class SATSolverTypesTest : public ::testing::Test {
 protected:
@@ -24,4 +25,6 @@ TEST_F(SATSolverTypesTest, test_ClauseIterator) {
         ASSERT_EQ(l, v[i]);
         i++;
     }
-}
\ No newline at end of file
+}
+
+}
